$set 14 #main

$ #RCRequiresArg
# viga: '-rc' vajab argumenti\n
$ #DISPLAYRequiresArg
# viga: '-display' vajab argumenti\n
$ #WarnDisplaySet
# hoiatus: ei saanud mrata keskonna muutujat 'DISPLAY'\n
$ #Usage
# Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
  -display <string>\t\tkasuta displei hendust.\n\
  -rc <string>\t\t\tkasuta alternatiivseid resursse.\n\
  -version\t\t\tnita versiooninumber ja vlju.\n\
  -info\t\t\t\tdisplay some useful information.\n\
  -log <filename>\t\t\tlog output to file.\n\
  -help\t\t\t\tnita seda abiteksti ja vlju.\n\n
$ #CompileOptions
# Kompileerimisoptsioonid:\n\
  Debuggimine\t\t\t%s\n\
  Pimimine:\t\t\t%s\n\
  Kuju:\t\t\t%s\n\
  Pragu:\t\t\t\t%s\n\
  8bpp mratud teravustamine:\t%s\n\n
